Changelog
=========
Version are structured like the following: ``<major>.<minor>.<bugfix>``. Unless
explicitly stated, changes are made by
`Andreas Runfalk <https://github.com/runfalk>`_.

Version 0.1.1
-------------
Released on 9th July 2017

- Fixed issue with new versions of sqlparse by bumping its version requirement

Version 0.1.0
-------------
Released on 19 July 2016

- Initial release
